@@ -160,9 +160,15 @@ do_worker_child(void)
 
 	for (;;)
 	{
+		WD_STATES	wd_status;
+
 		MemoryContextSwitchTo(WorkerMemoryContext);
 		MemoryContextResetAndDeleteChildren(WorkerMemoryContext);
-		WD_STATES	wd_status;
+		/*
+		 * Since WorkerMemoryContext is used for "slots", we need to clear it
+		 * so that new slots are allocated later on.
+		 */
+		memset(slots, 0, sizeof(slots));
 
 		CHECK_REQUEST;
 
@@ -189,7 +195,7 @@ do_worker_child(void)
 			Req_info->switching == false)
 		{
 			/*
-			 * Acquire follow primary lock. If fail to acqure lock, try again.
+			 * Acquire follow primary lock. If fail to acquire lock, try again.
 			 */
 			follow_primary_lock_acquired = false;
 
